pub struct WorldViewOptions {
pub paint_local_player: bool,
pub paint_overlays: bool,
}Expand description
Presentation flags for WorldView::build_with_options.
Fields
paint_local_player: boolPaint local player @ at view center (TUI). Gfx uses a sprite instead.
paint_overlays: boolPaint NPCs, resources, loot, chests, quest boards, entities into the cell grid. Gfx sets this false and draws those at continuous world coordinates.
Implementations
Sourceimpl WorldViewOptions
impl WorldViewOptions
Sourcepub fn terrain_only() -> Self
pub fn terrain_only() -> Self
Terrain / walls only — gfx draws movers at precise x,y.